@@ -11,6 +11,7 @@ unset https_proxy
 unset no_proxy
 
 adverb=
+test_timeout_multiplier=3
 
 if [ "$DEB_HOST_ARCH_BITS" = 64 ]; then
     # reprotest sometimes uses linux32 even for x86_64 builds, and
@@ -19,11 +20,7 @@ if [ "$DEB_HOST_ARCH_BITS" = 64 ]; then
 fi
 
 e=0
-$adverb dh_auto_test || e=$?
-
-find . -name 'test*.log' \
--not -name test-suite.log \
--print0 | xargs -0 tail -v -c1M
+$adverb dh_auto_test -- --timeout-multiplier "${test_timeout_multiplier}" || e=$?
 
 echo "Killing gpg-agent processes:"
 pgrep --list-full --full "gpg-agent --homedir /var/tmp/test-flatpak-.*" >&2 || :
